@@ -1,4 +1,3 @@
-/*
 extern crate gitlab_api as gitlab;
 
 use std::env;
@@ -7,7 +6,6 @@ extern crate log;
 extern crate env_logger;
 
 use gitlab::GitLab;
-use gitlab::merge_requests;
 
 
 fn main() {
@@ -35,14 +33,19 @@ fn main() {
 
     let gl = GitLab::new(&hostname, &token);
 
-    let merge_request = gl.merge_request(merge_requests::single::Listing::new(142, 418)).unwrap();
+    let project_id = 142;
+    let merge_requests_ids = vec![409, 410];
+    let merge_requests_iids = vec![3, 4];
+
+    let merge_requests = gl.merge_requests(project_id).list();
+    println!("merge_requests: {:?}", merge_requests);
+
+    let merge_request = gl.merge_requests(project_id).single(merge_requests_ids[0]).list();
     println!("merge_request: {:?}", merge_request);
 
-    let merge_requests = gl.merge_requests(merge_requests::Listing::new(142)).unwrap();
+    let merge_requests = gl.merge_requests(project_id).iid(vec![merge_requests_iids[0]]).list();
     println!("merge_requests: {:?}", merge_requests);
-}
-*/
 
-fn main() {
-    println!("Merge requests disabled until API stabilizes. See projects instead.");
+    // let merge_requests = gl.merge_requests(project_id).iid(merge_requests_iids).list();
+    // println!("merge_requests: {:?}", merge_requests);
 }
