@@ -2,7 +2,6 @@
 
 #![cfg_attr(feature="clippy", feature(plugin))]
 #![cfg_attr(feature="clippy", plugin(clippy))]
-#![cfg_attr(feature="cargo-clippy", allow(doc_markdown))]
 
 #![cfg_attr(feature = "serde_derive", feature(proc_macro))]
 
@@ -27,7 +26,7 @@ extern crate hyper;
 
 
 pub mod gitlab;
-// pub mod groups;
+pub mod groups;
 pub mod projects;
 pub mod issues;
 pub mod merge_requests;
